@@ -26,18 +26,18 @@ import (
 	"github.com/GoogleCloudPlatform/osconfig/e2e_tests/utils"
 	"github.com/golang/protobuf/jsonpb"
 
-	osconfigpb "google.golang.org/genproto/googleapis/cloud/osconfig/v1beta"
+	"cloud.google.com/go/osconfig/apiv1beta/osconfigpb"
 )
 
 const (
-	packageInstalled    = "osconfig_tests/pkg_installed"
-	packageNotInstalled = "osconfig_tests/pkg_not_installed"
-	osconfigTestRepo    = "osconfig-agent-test-repository"
-	testResourceBucket  = "osconfig-agent-end2end-test-resources"
-	yumTestRepoBaseURL  = "https://packages.cloud.google.com/yum/repos/osconfig-agent-test-repository"
-	aptTestRepoBaseURL  = "http://packages.cloud.google.com/apt"
-	gooTestRepoURL      = "https://packages.cloud.google.com/yuck/repos/osconfig-agent-test-repository"
-	aptRaptureGpgKey    = "https://packages.cloud.google.com/apt/doc/apt-key.gpg"
+	packageInstalled      = "osconfig_tests/pkg_installed"
+	packageNotInstalled   = "osconfig_tests/pkg_not_installed"
+	gcsfuseTestRepo       = "gcsfuse"
+	testResourceBucket    = "osconfig-agent-end2end-test-resources"
+	gcsfuseYumRepoBaseURL = "https://packages.cloud.google.com/yum/repos/gcsfuse-el7-x86_64"
+	aptTestRepoBaseURL    = "http://packages.cloud.google.com/apt"
+	gooTestRepoURL        = "https://packages.cloud.google.com/yuck/repos/osconfig-agent-test-repository"
+	aptRaptureGpgKey      = "https://packages.cloud.google.com/apt/doc/apt-key.gpg"
 )
 
 var (
@@ -86,15 +86,13 @@ func addPackageInstallTest(key string) []*guestPolicyTestSetup {
 func buildPkgUpdateTestSetup(name, image, pkgManager, key string) *guestPolicyTestSetup {
 	assertTimeout := 240 * time.Second
 	testName := packageUpdateFunction
-	packageName := "ed"
+	packageName := "gcsfuse"
 	machineType := "e2-medium"
 	if pkgManager == "googet" {
 		packageName = "cowsay"
 		machineType = "e2-standard-4"
 	}
-	if pkgManager == "zypper" {
-		packageName = "cowsay"
-	}
+
 	instanceName := fmt.Sprintf("%s-%s-%s-%s", path.Base(name), testName, key, utils.RandString(3))
 	gp := &osconfigpb.GuestPolicy{
 		Packages:   osconfigserver.BuildPackagePolicy(nil, nil, []string{packageName}),
@@ -124,15 +122,12 @@ func addPackageUpdateTest(key string) []*guestPolicyTestSetup {
 func buildPkgDoesNotUpdateTestSetup(name, image, pkgManager, key string) *guestPolicyTestSetup {
 	assertTimeout := 240 * time.Second
 	testName := packageNoUpdateFunction
-	packageName := "ed"
+	packageName := "gcsfuse"
 	machineType := "e2-medium"
 	if pkgManager == "googet" {
 		packageName = "cowsay"
 		machineType = "e2-standard-4"
 	}
-	if pkgManager == "zypper" {
-		packageName = "cowsay"
-	}
 
 	instanceName := fmt.Sprintf("%s-%s-%s-%s", path.Base(name), testName, key, utils.RandString(3))
 	gp := &osconfigpb.GuestPolicy{
@@ -198,22 +193,29 @@ func addPackageRemovalTest(key string) []*guestPolicyTestSetup {
 
 func buildPkgInstallFromNewRepoTestSetup(name, image, pkgManager, key string) *guestPolicyTestSetup {
 	assertTimeout := 120 * time.Second
-	packageName := "osconfig-agent-test"
+	packageName := "gcsfuse"
 	testName := packageInstallFromNewRepoFunction
 	machineType := "e2-medium"
 	if pkgManager == "googet" {
 		machineType = "e2-standard-2"
 	}
 
+	// TODO: use another test pkg for Windows
+	if strings.Contains(image, "windows") {
+		packageName = "osconfig-agent-test"
+	}
+
+	gcsfuseAptRepoBane := fmt.Sprintf("gcsfuse-%s", utils.GetDebOsName(image))
+
 	instanceName := fmt.Sprintf("%s-%s-%s-%s", path.Base(name), testName, key, utils.RandString(3))
 	gp := &osconfigpb.GuestPolicy{
 		// Test that upgrade also installs.
 		Packages:   osconfigserver.BuildPackagePolicy(nil, nil, []string{packageName}),
 		Assignment: &osconfigpb.Assignment{InstanceNamePrefixes: []string{instanceName}},
 		PackageRepositories: []*osconfigpb.PackageRepository{
-			{Repository: osconfigserver.BuildAptRepository(osconfigpb.AptRepository_DEB, aptTestRepoBaseURL, osconfigTestRepo, aptRaptureGpgKey, []string{"main"})},
-			{Repository: osconfigserver.BuildYumRepository(osconfigTestRepo, "Google OSConfig Agent Test Repository", yumTestRepoBaseURL, yumRaptureGpgKeys)},
-			{Repository: osconfigserver.BuildZypperRepository(osconfigTestRepo, "Google OSConfig Agent Test Repository", yumTestRepoBaseURL, yumRaptureGpgKeys)},
+			{Repository: osconfigserver.BuildAptRepository(osconfigpb.AptRepository_DEB, aptTestRepoBaseURL, gcsfuseAptRepoBane, aptRaptureGpgKey, []string{"main"})},
+			{Repository: osconfigserver.BuildYumRepository(gcsfuseTestRepo, "gcsfuse", gcsfuseYumRepoBaseURL, yumRaptureGpgKeys)},
+			{Repository: osconfigserver.BuildZypperRepository(gcsfuseTestRepo, "gcsfuse", gcsfuseYumRepoBaseURL, yumRaptureGpgKeys)},
 			{Repository: osconfigserver.BuildGooRepository("Google OSConfig Agent Test Repository", gooTestRepoURL)},
 		},
 	}
