@@ -27,16 +27,16 @@ import (
 )
 
 const (
-	packageInstalled    = "osconfig_tests/pkg_installed"
-	packageNotInstalled = "osconfig_tests/pkg_not_installed"
-	fileExists          = "osconfig_tests/file_exists"
-	fileDNE             = "osconfig_tests/file_does_not_exist"
-	osconfigTestRepo    = "osconfig-agent-test-repository"
-	testResourceBucket  = "osconfig-agent-end2end-test-resources"
-	yumTestRepoBaseURL  = "https://packages.cloud.google.com/yum/repos/osconfig-agent-test-repository"
-	aptTestRepoBaseURL  = "http://packages.cloud.google.com/apt"
-	gooTestRepoURL      = "https://packages.cloud.google.com/yuck/repos/osconfig-agent-test-repository"
-	aptRaptureGpgKey    = "https://packages.cloud.google.com/apt/doc/apt-key.gpg"
+	packageInstalled      = "osconfig_tests/pkg_installed"
+	packageNotInstalled   = "osconfig_tests/pkg_not_installed"
+	fileExists            = "osconfig_tests/file_exists"
+	fileDNE               = "osconfig_tests/file_does_not_exist"
+	gcsfuseTestRepo       = "gcsfuse"
+	testResourceBucket    = "osconfig-agent-end2end-test-resources"
+	gcsfuseYumRepoBaseURL = "https://packages.cloud.google.com/yum/repos/gcsfuse-el7-x86_64"
+	aptTestRepoBaseURL    = "http://packages.cloud.google.com/apt"
+	gooTestRepoURL        = "https://packages.cloud.google.com/yuck/repos/osconfig-agent-test-repository"
+	aptRaptureGpgKey      = "https://packages.cloud.google.com/apt/doc/apt-key.gpg"
 )
 
 var (
@@ -279,7 +279,7 @@ func buildDebTestSetup(name, image, key string) *osPolicyTestSetup {
 													Type: &osconfigpb.OSPolicy_Resource_File_Remote_{
 														Remote: &osconfigpb.OSPolicy_Resource_File_Remote{
 															Uri:            "https://storage.googleapis.com/osconfig-agent-end2end-test-resources/OSPolicies/google-chrome-stable_current_amd64.deb",
-															Sha256Checksum: "43f141970ab61d9c5a993dcf094625d9a7a1d24212a3c2443e7092b40c3a354c",
+															Sha256Checksum: "3ec1cadbb55cf66cc51f0421eace324a88836ee2d982b945b8f67a3f131b0924",
 														},
 													},
 												},
@@ -485,8 +485,8 @@ func buildRpmTestSetup(name, image, key string) *osPolicyTestSetup {
 												Source: &osconfigpb.OSPolicy_Resource_File{
 													Type: &osconfigpb.OSPolicy_Resource_File_Remote_{
 														Remote: &osconfigpb.OSPolicy_Resource_File_Remote{
-															Uri:            "https://storage.googleapis.com/osconfig-agent-end2end-test-resources/OSPolicies/google-chrome-stable_current_x86_64.rpm",
-															Sha256Checksum: "8c547dc36bda13740b12e2a74aa8388e459fa53c95190327d16cb849412a0103",
+															Uri:            "https://storage.googleapis.com/osconfig-agent-end2end-test-resources/OSPolicies/gcsfuse-2.0.1-1.x86_64.rpm",
+															Sha256Checksum: "92475edeba03e6f7870d30a063d9c19767e6a4f7b0107a2af9191849d4b7a44f",
 														},
 													},
 												},
@@ -608,8 +608,8 @@ func buildMsiTestSetup(name, image, key string) *osPolicyTestSetup {
 													Type: &osconfigpb.OSPolicy_Resource_File_Gcs_{
 														Gcs: &osconfigpb.OSPolicy_Resource_File_Gcs{
 															Bucket:     testResourceBucket,
-															Object:     "OSPolicies/GoogleChromeStandaloneEnterprise64.msi",
-															Generation: 1618590043841384,
+															Object:     "OSPolicies/googlechromestandaloneenterprise64.msi",
+															Generation: 1720172515592258,
 														},
 													},
 												},
@@ -677,10 +677,12 @@ func addPackageResourceTests(key string) []*osPolicyTestSetup {
 
 func buildAptRepositoryResourceTest(name, image, key string) *osPolicyTestSetup {
 	assertTimeout := 360 * time.Second
-	packageName := "osconfig-agent-test"
+	packageName := "gcsfuse"
 	testName := repositoryResourceApt
 	machineType := "e2-medium"
 
+	gcsfuseAptRepoBane := fmt.Sprintf("gcsfuse-%s", utils.GetDebOsName(image))
+
 	instanceName := fmt.Sprintf("%s-%s-%s-%s", path.Base(name), testName, key, utils.RandString(3))
 	ospa := &osconfigpb.OSPolicyAssignment{
 		InstanceFilter: &osconfigpb.OSPolicyAssignment_InstanceFilter{
@@ -707,7 +709,7 @@ func buildAptRepositoryResourceTest(name, image, key string) *osPolicyTestSetup
 											Apt: &osconfigpb.OSPolicy_Resource_RepositoryResource_AptRepository{
 												ArchiveType:  osconfigpb.OSPolicy_Resource_RepositoryResource_AptRepository_DEB,
 												Uri:          aptTestRepoBaseURL,
-												Distribution: osconfigTestRepo,
+												Distribution: gcsfuseAptRepoBane,
 												Components:   []string{"main"},
 												GpgKey:       aptRaptureGpgKey,
 											},
@@ -745,7 +747,7 @@ func buildAptRepositoryResourceTest(name, image, key string) *osPolicyTestSetup
 
 func buildYumRepositoryResourceTest(name, image, key string) *osPolicyTestSetup {
 	assertTimeout := 360 * time.Second
-	packageName := "osconfig-agent-test"
+	packageName := "gcsfuse"
 	testName := repositoryResourceYum
 	machineType := "e2-medium"
 
@@ -773,9 +775,9 @@ func buildYumRepositoryResourceTest(name, image, key string) *osPolicyTestSetup
 									Repository: &osconfigpb.OSPolicy_Resource_RepositoryResource{
 										Repository: &osconfigpb.OSPolicy_Resource_RepositoryResource_Yum{
 											Yum: &osconfigpb.OSPolicy_Resource_RepositoryResource_YumRepository{
-												Id:          osconfigTestRepo,
-												DisplayName: "Google OSConfig Agent Test Repository",
-												BaseUrl:     yumTestRepoBaseURL,
+												Id:          gcsfuseTestRepo,
+												DisplayName: "gcsfuse",
+												BaseUrl:     gcsfuseYumRepoBaseURL,
 												GpgKeys:     yumRaptureGpgKeys,
 											},
 										},
@@ -812,7 +814,7 @@ func buildYumRepositoryResourceTest(name, image, key string) *osPolicyTestSetup
 
 func buildZypperRepositoryResourceTest(name, image, key string) *osPolicyTestSetup {
 	assertTimeout := 360 * time.Second
-	packageName := "osconfig-agent-test"
+	packageName := "gcsfuse"
 	testName := repositoryResourceZypper
 	machineType := "e2-medium"
 
@@ -840,9 +842,9 @@ func buildZypperRepositoryResourceTest(name, image, key string) *osPolicyTestSet
 									Repository: &osconfigpb.OSPolicy_Resource_RepositoryResource{
 										Repository: &osconfigpb.OSPolicy_Resource_RepositoryResource_Zypper{
 											Zypper: &osconfigpb.OSPolicy_Resource_RepositoryResource_ZypperRepository{
-												Id:          osconfigTestRepo,
-												DisplayName: "Google OSConfig Agent Test Repository",
-												BaseUrl:     yumTestRepoBaseURL,
+												Id:          gcsfuseTestRepo,
+												DisplayName: "gcsfuse",
+												BaseUrl:     gcsfuseYumRepoBaseURL,
 												GpgKeys:     yumRaptureGpgKeys,
 											},
 										},
@@ -951,6 +953,10 @@ func addRepositoryResourceTests(key string) []*osPolicyTestSetup {
 		pkgTestSetup = append(pkgTestSetup, buildYumRepositoryResourceTest(name, image, key))
 	}
 	for name, image := range utils.HeadSUSEImages {
+		// TODO: remove this if conditon after SUSE fixes repo-file overwriting issue for SLES-12
+		if strings.Contains(image, "sles-12") {
+			continue
+		}
 		pkgTestSetup = append(pkgTestSetup, buildZypperRepositoryResourceTest(name, image, key))
 	}
 	for name, image := range utils.HeadWindowsImages {
