@@ -23,7 +23,7 @@ import (
 	"strings"
 	"testing"
 
-	agentendpointpb "google.golang.org/genproto/googleapis/cloud/osconfig/agentendpoint/v1beta"
+	"cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb"
 )
 
 func runAptRepositories(ctx context.Context, repos []*agentendpointpb.AptRepository) (string, error) {
@@ -90,10 +90,6 @@ func TestGetAptGPGKey(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	if len(entityList) != 2 {
-		t.Errorf("Expected: %v key(s), got: %v", 2, len(entityList))
-	}
-
 	// check if Artifact Regitry key exist or not
 	artifactRegistryKeyFound := false
 	for _, e := range entityList {
